.. contents::

=================
Inplace Edit Form
=================

Information
===========

.. image:: https://travis-ci.org/Yaco-Sistemas/django-inplaceedit.png?branch=master
    :target: https://travis-ci.org/Yaco-Sistemas/django-inplaceedit

.. image:: https://badge.fury.io/py/django-inplaceedit.png
    :target: https://badge.fury.io/py/django-inplaceedit

.. image:: https://pypip.in/d/django-inplaceedit/badge.png
    :target: https://pypi.python.org/pypi/django-inplaceedit

Inplace Edit Form is a Django application that allows you to inline edition of some data from the database

It is distributed under the terms of the GNU Lesser General Public
License <http://www.gnu.org/licenses/lgpl.html>

Demo (this video use a very old version of django-inplaceedit)
==============================================================

Video Demo, of django-inplaceedit, `django-inplaceedit-extra-fields <http://pypi.python.org/pypi/django-inplaceedit-extra-fields>`_ and `django-inlinetrans <http://pypi.python.org/pypi/django-inlinetrans>`_ (Set full screen mode to view it correctly)

.. image:: https://github.com/Yaco-Sistemas/django-inplaceedit/raw/master/video-frame.png
   :target: http://youtu.be/_EjisXtMy_Y?t=34s


Requirements
============

 * `Django <https://www.djangoproject.com/>`_ (>= 1.2, even works with 1.1 with some customizations in your project)
 * `jQuery <http://jquery.com/>`_ (>=1.5.0)


Other packages related
======================

 * `Transmeta <http://pypi.python.org/pypi/django-transmeta>`_
 * `Django Inplace Edit Extra Field <http://pypi.python.org/pypi/django-inplaceedit-extra-fields>`_
 * `Django Inplace Edit Bootstrap <http://pypi.python.org/pypi/django-inplaceedit-bootstrap>`_

Documentation
=============

You can find more in the documentation at https://django-inplaceedit.readthedocs.org/en/latest/

Development
===========

You can get the last bleeding edge version of inplaceedit by doing a checkout
of its git repository::

  git clone git://github.com/Yaco-Sistemas/django-inplaceedit.git
